/*Variables to use for setup*/

/*Change this if the database has a different name*/
USE [PrickaBokslut]
SET NOEXEC OFF;

/************************************************************
**
** Check for admin rights
**
************************************************************/
IF NOT EXISTS (SELECT (SELECT HAS_PERMS_BY_NAME(null, null, 'CONTROL SERVER')) WHERE (SELECT HAS_PERMS_BY_NAME(null, null, 'CONTROL SERVER')) = 1)

BEGIN
PRINT 'Script needs to be run as Admin!'
raiserror('Script needs to be run as Admin!', 20, -1) with log
END



/* Read the current version from the database */
IF OBJECT_ID('tempdb.dbo.#upgrade', 'U') IS NOT NULL 
    DROP TABLE #upgrade;

CREATE TABLE #upgrade(CurrentVersion int)
GO
Insert Into #upgrade Select DBVersion FROM GeneralSettings;
GO
DECLARE @CurrentVersion int;
SELECT @CurrentVersion = CurrentVersion FROM #upgrade;
PRINT 'Current version: ' + STR(@CurrentVersion);

IF (SELECT CurrentVersion FROM #upgrade) < 12
BEGIN
 PRINT 'The script does not support versions earlier than 12. Please contact Pricka AB';
 SET NOEXEC ON;
END


/************************************************************
**
** Upgrade to version 13.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 12
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 13';
GO

/************************************************* UPDATE DB 13 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 13 WHERE DBVersion = 12
ALTER TABLE [dbo].[GeneralSettings] ADD [Reseller] [smallint] NOT NULL DEFAULT 0

/****** Object:  Table [dbo].[Schedules]    Script Date: 2016-04-14 08:31:32 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[Schedules](
	[ScheduleID] [int] IDENTITY(1,1) NOT NULL,
	[EntityID] [int] NOT NULL,
	[PeriodNr] [int] NULL,
	[Name] [nvarchar](256) NOT NULL,
	[PeriodStartDay] [smallint] NOT NULL,
	[PeriodEndDay] [smallint] NOT NULL,
	[MonthAfter] [bit] NOT NULL,
	[SendDisapproved] [bit] NOT NULL,
	[SendBalanceChanges] [bit] NOT NULL,
	[EndDayPrio1] [smallint] NOT NULL,
	[EndDayPrio2] [smallint] NOT NULL,
	[EndDayPrio3] [smallint] NOT NULL,
	[EndDayPrio4] [smallint] NOT NULL,
	[EndDayPrio5] [smallint] NOT NULL
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[Schedules]  WITH CHECK ADD  CONSTRAINT [FK_Schedules_Entities] FOREIGN KEY([EntityID])
REFERENCES [dbo].[Entities] ([EntityID])
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[Schedules] CHECK CONSTRAINT [FK_Schedules_Entities]
GO


/****** Object:  Table [dbo].[Mail]    Script Date: 2016-05-30 11:02:57 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[Mail](
	[MailID] [bigint] IDENTITY(1,1) NOT NULL,
	[Subject] [nvarchar](256) NOT NULL,
	[Body] [nvarchar](max) NOT NULL,
	[BodyFormat] [nvarchar](10) NOT NULL,
	[MailReciver] [nvarchar](max) NOT NULL,
	[Importance] [nvarchar](10) NOT NULL,
	[CreationDate] [datetime] NOT NULL CONSTRAINT [DF_Mail_CreationDate]  DEFAULT (getdate()),
	[CreationUserID] [int] NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
ALTER TABLE [dbo].[ReconGroups] ADD [PriorityLevel] [tinyint] NULL
GO
ALTER TABLE [dbo].[ReconGroups] ADD [FourEyesPrinciple] [bit] NULL
GO
ALTER TABLE [dbo].[ReconGroups] ADD [Filter] [nvarchar] (256) NULL
GO
ALTER TABLE [dbo].[Periods] ADD [ScheduleID] [int] NULL
GO
ALTER TABLE [dbo].[GeneralSettings] ADD [UseSameSchedulesAllEntities] [bit] NOT NULL DEFAULT 0
GO
ALTER TABLE [dbo].[Archiving] ADD [ArchivingOwner] [int] NULL
GO

IF NOT EXISTS (SELECT 1 FROM dbo.Schedules)
BEGIN

DECLARE @LoopCounter INT , @MaxntityIDId INT, @EntityID INT
SELECT @LoopCounter = min(EntityID) , @MaxntityIDId = max(EntityID) 
FROM Entities
 
WHILE ( @LoopCounter IS NOT NULL
        AND  @LoopCounter <= @MaxntityIDId)
BEGIN
   SELECT @EntityID = EntityID FROM Entities 
   WHERE EntityID = @LoopCounter
   
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 1, N'01', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 2, N'02', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 3, N'03', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 4, N'04', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 5, N'05', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 6, N'06', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 7, N'07', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 8, N'08', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 9, N'09', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 10, N'10', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 11, N'11', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)
INSERT [dbo].[Schedules] ([EntityID], [PeriodNr], [Name], [PeriodStartDay], [PeriodEndDay], [MonthAfter], [SendDisapproved], [SendBalanceChanges], [EndDayPrio1], [EndDayPrio2], [EndDayPrio3], [EndDayPrio4], [EndDayPrio5]) 
VALUES (@EntityID, 12, N'12', 1, 10, 1, 1, 1, 3, 4, 5, 6, 8)

   PRINT @EntityID  
  
   SELECT @LoopCounter = min(EntityID) FROM Entities
   WHERE EntityID > @LoopCounter
END

END
GO

/****** Object:  StoredProcedure [dbo].[PBSendMail]    Script Date: 2016-05-31 12:58:35 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:		<Pricka AB>
-- Create date: <2016-08-16>
-- Description:	<Sending mail from dbo.mail>
-- =============================================
CREATE PROCEDURE [dbo].[PBSendMail] 
AS
BEGIN
	SET NOCOUNT ON;
DECLARE @MailReciver NVARCHAR(MAX), @Subject NVARCHAR(256), @Body NVARCHAR(MAX), @BodyFormat NVARCHAR(10), @Importance NVARCHAR(10)
DECLARE @MailID INT, @Max_ID INT

SELECT @MailID = MIN(MailID), @Max_ID = MAX(MailID) FROM dbo.Mail

WHILE @MailID <= @Max_ID
 BEGIN
    SELECT 
	@MailReciver = MailReciver,
	@Subject = [Subject],
	@Body = Body,
	@BodyFormat = BodyFormat,
	@Importance = Importance
    FROM dbo.Mail
	WHERE MailID = @MailID
	
	IF @MailReciver IS NOT NULL
	BEGIN
	EXEC msdb.dbo.sp_send_dbmail 
         @profile_name = 'PrickaBokslutProfile',
         @recipients = @MailReciver,
         @from_address = '',
         @reply_to = '',
         @subject = @Subject,
         @body = @Body,
         @body_format = @BodyFormat,
         @importance = @Importance;
        PRINT 'Mail sent: ' + CAST(@MailID AS NVARCHAR(30))
	 END
   ELSE
     BEGIN
        PRINT 'Mail not sent'
     END

	 SELECT @MailID = MIN(MailID) FROM dbo.Mail WHERE MailID > @MailID
 END
 DELETE FROM dbo.Mail
END
GO
/************************************************ END UPDATE DB 13 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF;
/************************************************************
**
** Upgrade to version 14.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 13
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 14';
GO

/************************************************* UPDATE TO DB 14 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 14 WHERE DBVersion = 13
GO
ALTER TABLE [dbo].[ReconGroups] ADD [Settings] [nvarchar](max) NULL
GO
ALTER TABLE [dbo].[ReconGroups] ADD [RGSettingsID] [int] NULL
GO
CREATE TABLE [dbo].[RGSettings](
	[RGSettingsID] [int] IDENTITY(1,1) NOT NULL,
	[SettingsName] [nvarchar](256) NOT NULL,
	[Settings] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_RGSettings] PRIMARY KEY CLUSTERED 
(
	[RGSettingsID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
ALTER TABLE [dbo].[Users] ADD [AbsenceActivated] [bit] NULL
GO
ALTER TABLE [dbo].[Users] ADD [AbsenceStartDate] [datetime] NULL
GO
ALTER TABLE [dbo].[Users] ADD [AbsenceEndDate] [datetime] NULL
GO
ALTER TABLE [dbo].[Users] ADD [AbsenceMessage] [nvarchar](max) NULL
GO
CREATE TABLE [dbo].[AbsenceSubstitute](
	[UserID] [int] NOT NULL,
	[SubstituteUserID] [int] NOT NULL
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[AbsenceSubstitute]  WITH CHECK ADD  CONSTRAINT [FK_AbsenceSubstitute_Users] FOREIGN KEY([UserID])
REFERENCES [dbo].[Users] ([UserID])
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[AbsenceSubstitute] CHECK CONSTRAINT [FK_AbsenceSubstitute_Users]
GO
ALTER TABLE [dbo].[Tasks] ADD [Filter] [nvarchar](256) NULL
GO
ALTER TABLE [dbo].[Tasks] ADD [Archive] [bit] NULL
GO
ALTER TABLE [dbo].[Tasks] ADD [PriorityLevel] [tinyint] NULL
GO
ALTER TABLE [dbo].[Tasks] ADD [ExecutorAttached] [nvarchar](max) NULL
GO
/****** Object:  Table [dbo].[Calendars]    Script Date: 2017-01-27 10:38:34 ******/
CREATE TABLE [dbo].[Calendars](
	[CalendarID] [int] IDENTITY(1,1) NOT NULL,
	[UpdateDate] [datetime] NOT NULL,
	[Name] [nvarchar](256) NOT NULL,
	[Custom] [bit] NOT NULL,
	[Country] [nvarchar](256) NULL,
	[CountryCode] [nvarchar](10) NULL,
	[Region] [nvarchar](256) NULL,
	[PublicHolidaysXML] [nvarchar](max) NOT NULL,
	[ICSFile] [nvarchar](max) NULL,
 CONSTRAINT [PK_Calendars] PRIMARY KEY CLUSTERED 
(
	[CalendarID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

ALTER TABLE [dbo].[Calendars] ADD  CONSTRAINT [DF_Calendars_ArchivingDate]  DEFAULT (getdate()) FOR [UpdateDate]
GO
GO
ALTER TABLE [dbo].[Entities] ADD [CalendarID] [int] NULL
GO
ALTER TABLE [dbo].[ReconGroups] ADD [CopyFromPrevious] [bit] NULL
GO
ALTER TABLE [dbo].[Tasks] ADD [LastUpdated] [datetime] NULL
GO
/************************************************ END UPDATE TO DB 14 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF;

/************************************************************
**
** Upgrade to version 15.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 14
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 15';
GO

/************************************************* UPDATE TO DB 15 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 15 WHERE DBVersion = 14
GO
ALTER TABLE [dbo].[ReconGroups] ALTER COLUMN [Description] NVARCHAR(max) NULL
ALTER TABLE [dbo].[ReconGroups] ADD [LastModifiedUserID] [int] NULL
ALTER TABLE [dbo].[ReconGroups] ADD [LastModifiedDate] [datetime] NULL
ALTER TABLE [dbo].[ReconGroups] ADD [PKECType] [smallint] NULL
ALTER TABLE [dbo].[ReconGroups] ADD [PKReadMethod] [smallint] NULL
ALTER TABLE [dbo].[ImportInterfaces] ADD [ResetNotImportedAccounts] [bit] NULL
ALTER TABLE [dbo].[ImportInterfaces] ADD [AutoGenerateParameterValues] [bit] NULL
ALTER TABLE [dbo].[Tasks] ADD [LastModifiedUserID] [int] NULL

EXEC SP_RENAME 'Tasks.LastUpdated', 'LastModifiedDate' , 'COLUMN';
GO
DELETE FROM ColumnsSettings
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Account', N'Account', 1, 1)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Period', N'Period', 0, 2)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Date1', N'Date1', 1, 3)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Date2', N'Date2', 0, 4)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'RefType', N'RefType', 1, 5)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Ref', N'Referens', 1, 6)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Amount', N'Amount', 1, 7)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Text', N'Text', 1, 8)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Notes', N'Notes', 1, 9)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra1', N'Extra1', 0, 10)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra2', N'Extra2', 0, 11)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra3', N'Extra3', 0, 12)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra4', N'Extra4', 0, 13)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra5', N'Extra5', 0, 14)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra6', N'Extra6', 0, 15)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra7', N'Extra7', 0, 16)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra8', N'Extra8', 0, 17)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra9', N'Extra9', 0, 18)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Amount2', N'Amount2', 0, 19)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra10', N'Extra10', 0, 20)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra11', N'Extra11', 0, 21)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra12', N'Extra12', 0, 22)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra13', N'Extra13', 0, 23)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra14', N'Extra14', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra15', N'Extra15', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra16', N'Extra16', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra17', N'Extra17', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra18', N'Extra18', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra19', N'Extra19', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra20', N'Extra20', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra21', N'Extra21', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra22', N'Extra22', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra23', N'Extra23', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra24', N'Extra24', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra25', N'Extra25', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra26', N'Extra26', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra27', N'Extra27', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra28', N'Extra28', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra29', N'Extra29', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (1, N'Default_en', N'Extra30', N'Extra30', 0, 40)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Account', N'Konto', 1, 1)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Period', N'Period', 0, 2)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Date1', N'Datum1', 1, 3)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Date2', N'Datum2', 0, 4)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'RefType', N'RefTyp', 1, 5)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Ref', N'Referens', 1, 6)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Amount', N'Belopp', 1, 7)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Text', N'Text', 1, 8)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Notes', N'Anteckningar', 1, 9)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra1', N'Extra1', 0, 10)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra2', N'Extra2', 0, 11)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra3', N'Extra3', 0, 12)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra4', N'Extra4', 0, 13)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra5', N'Extra5', 0, 14)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra6', N'Extra6', 0, 15)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra7', N'Extra7', 0, 16)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra8', N'Extra8', 0, 17)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra9', N'Extra9', 0, 18)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Amount2', N'Amount2', 0, 19)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra10', N'Extra10', 0, 20)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra11', N'Extra11', 0, 21)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra12', N'Extra12', 0, 22)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra13', N'Extra13', 0, 23)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra14', N'Extra14', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra15', N'Extra15', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra16', N'Extra16', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra17', N'Extra17', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra18', N'Extra18', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra19', N'Extra19', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra20', N'Extra20', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra21', N'Extra21', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra22', N'Extra22', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra23', N'Extra23', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra24', N'Extra24', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra25', N'Extra25', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra26', N'Extra26', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra27', N'Extra27', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra28', N'Extra28', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra29', N'Extra29', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (2, N'Default_sv', N'Extra30', N'Extra30', 0, 40)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Account', N'Account', 1, 1)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Period', N'Period', 0, 2)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Date1', N'Date1', 1, 3)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Date2', N'Date2', 0, 4)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'RefType', N'RefType', 1, 5)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Ref', N'Referens', 1, 6)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Amount', N'Amount', 1, 7)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Text', N'Text', 1, 8)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Notes', N'Notes', 1, 9)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra1', N'Extra1', 0, 10)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra2', N'Extra2', 0, 11)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra3', N'Extra3', 0, 12)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra4', N'Extra4', 0, 13)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra5', N'Extra5', 0, 14)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra6', N'Extra6', 0, 15)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra7', N'Extra7', 0, 16)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra8', N'Extra8', 0, 17)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra9', N'Extra9', 0, 18)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Amount2', N'Amount2', 0, 19)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra10', N'Extra10', 0, 20)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra11', N'Extra11', 0, 21)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra12', N'Extra12', 0, 22)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra13', N'Extra13', 0, 23)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra14', N'Extra14', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra15', N'Extra15', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra16', N'Extra16', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra17', N'Extra17', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra18', N'Extra18', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra19', N'Extra19', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra20', N'Extra20', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra21', N'Extra21', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra22', N'Extra22', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra23', N'Extra23', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra24', N'Extra24', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra25', N'Extra25', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra26', N'Extra26', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra27', N'Extra27', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra28', N'Extra28', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra29', N'Extra29', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (3, N'Default_dk', N'Extra30', N'Extra30', 0, 40)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Account', N'Konto', 1, 1)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Period', N'Periode', 0, 2)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Date1', N'Dato1', 1, 3)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Date2', N'Dato2', 0, 4)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'RefType', N'ReferanseType', 1, 5)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Ref', N'Referanse', 1, 6)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Amount', N'Belp', 1, 7)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Text', N'Tekst', 1, 8)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Notes', N'Notater', 1, 9)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra1', N'Ekstra1', 0, 10)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra2', N'Ekstra2', 0, 11)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra3', N'Ekstra3', 0, 12)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra4', N'Ekstra4', 0, 13)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra5', N'Ekstra5', 0, 14)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra6', N'Ekstra6', 0, 15)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra7', N'Ekstra7', 0, 16)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra8', N'Ekstra8', 0, 17)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra9', N'Ekstra9', 0, 18)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Amount2', N'Amount2', 0, 19)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra10', N'Extra10', 0, 20)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra11', N'Extra11', 0, 21)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra12', N'Extra12', 0, 22)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra13', N'Extra13', 0, 23)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra14', N'Extra14', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra15', N'Extra15', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra16', N'Extra16', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra17', N'Extra17', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra18', N'Extra18', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra19', N'Extra19', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra20', N'Extra20', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra21', N'Extra21', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra22', N'Extra22', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra23', N'Extra23', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra24', N'Extra24', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra25', N'Extra25', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra26', N'Extra26', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra27', N'Extra27', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra28', N'Extra28', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra29', N'Extra29', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra30', N'Extra30', 0, 40)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Account', N'Account', 1, 1)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Period', N'Period', 0, 2)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Date1', N'Date1', 1, 3)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Date2', N'Date2', 0, 4)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'RefType', N'RefType', 1, 5)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Ref', N'Referens', 1, 6)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Amount', N'Amount', 1, 7)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Text', N'Text', 1, 8)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Notes', N'Notes', 1, 9)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra1', N'Extra1', 0, 10)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra2', N'Extra2', 0, 11)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra3', N'Extra3', 0, 12)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra4', N'Extra4', 0, 13)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra5', N'Extra5', 0, 14)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra6', N'Extra6', 0, 15)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra7', N'Extra7', 0, 16)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra8', N'Extra8', 0, 17)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra9', N'Extra9', 0, 18)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Amount2', N'Amount2', 0, 19)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra10', N'Extra10', 0, 20)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra11', N'Extra11', 0, 21)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra12', N'Extra12', 0, 22)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra13', N'Extra13', 0, 23)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra14', N'Extra14', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra15', N'Extra15', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra16', N'Extra16', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra17', N'Extra17', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra18', N'Extra18', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra19', N'Extra19', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra20', N'Extra20', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra21', N'Extra21', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra22', N'Extra22', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra23', N'Extra23', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra24', N'Extra24', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra25', N'Extra25', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra26', N'Extra26', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra28', N'Extra28', 0, 43)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra29', N'Extra29', 0, 44)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (4, N'Default_no', N'Extra30', N'Extra30', 0, 45)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Amount2', N'Amount2', 0, 24)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra10', N'Extra10', 0, 25)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra11', N'Extra11', 0, 26)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra12', N'Extra12', 0, 27)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra13', N'Extra13', 0, 28)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra14', N'Extra14', 0, 29)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra15', N'Extra15', 0, 30)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra16', N'Extra16', 0, 31)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra17', N'Extra17', 0, 32)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra18', N'Extra18', 0, 33)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra19', N'Extra19', 0, 34)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra20', N'Extra20', 0, 35)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra21', N'Extra21', 0, 36)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra22', N'Extra22', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra23', N'Extra23', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra24', N'Extra24', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra25', N'Extra25', 0, 40)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra26', N'Extra26', 0, 41)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra27', N'Extra27', 0, 42)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra28', N'Extra28', 0, 43)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra29', N'Extra29', 0, 44)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra30', N'Extra30', 0, 45)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra27', N'Extra27', 0, 37)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra28', N'Extra28', 0, 38)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra29', N'Extra29', 0, 39)
GO
INSERT [dbo].[ColumnsSettings] ([ColumnsSettingsID], [ColumnsSettingsName], [ColumnName], [GridColumnName], [ShowColumn], [Order]) VALUES (5, N'Default_fi', N'Extra30', N'Extra30', 0, 40)
GO


--Update 1.5.2.0 START Moving DocXML from Archiving to ReconGroups--
SET NOEXEC OFF
GO
IF COL_LENGTH('dbo.ReconGroups', 'DocXML') IS NULL
ALTER TABLE [dbo].[ReconGroups] ADD [DocXML] NVARCHAR(max) NULL

IF (SELECT DBVersion FROM dbo.GeneralSettings) = 15 AND (SELECT COUNT(ArchiveType) FROM dbo.Archiving WHERE ArchiveType = 1) != 0
BEGIN
SET NOEXEC OFF
PRINT 'Updating to 1.5.2'
END
ELSE
BEGIN
SET NOEXEC ON
END


GO

If Object_Id('Tempdb..#TempRG') IS NOT NULL DROP TABLE #TempRG

SELECT 
  ReconGroupID 
INTO #TempRG
FROM ReconGroups 

BEGIN

DECLARE @LoopCounter INT , @MaxRGID INT, @ReconGroupID INT
SELECT @LoopCounter = min(ReconGroupID) , @MaxRGID = max(ReconGroupID) 
FROM #TempRG
	
	WHILE ( @LoopCounter IS NOT NULL
	        AND  @LoopCounter <= @MaxRGID)
			BEGIN
			SELECT @ReconGroupID = ReconGroupID FROM #TempRG WHERE ReconGroupID = @LoopCounter

			   PRINT 'Updating ReconGroupID: ' + CONVERT(varchar(20), @ReconGroupID)
			   
			   UPDATE ReconGroups SET DocXML = (SELECT TOP 1 Archiving.DocXML FROM dbo.Archiving WHERE
  Archiving.ArchiveType = 1 AND 
  Archiving.ReconGroupID = @ReconGroupID AND
  Archiving.DocXML IS NOT NULL) WHERE ReconGroupID = @ReconGroupID

SELECT @LoopCounter = min(ReconGroupID) FROM #TempRG
   WHERE ReconGroupID > @LoopCounter
	        END
END

UPDATE Archiving SET ArchiveType = 0 WHERE ArchiveType = 1
GO

SET NOEXEC OFF
IF (SELECT DBVersion FROM dbo.GeneralSettings) < 15
BEGIN
SET NOEXEC ON
END

--END Update 1.5.2.0 Moving DocXML from Archiving to ReconGroups--
/************************************************ END UPDATE TO DB 15 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF;
/************************************************************
**
** Upgrade to version 16.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 15
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 16';
GO

/************************************************* UPDATE TO DB 16 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 16 WHERE DBVersion = 15
GO
/************************************************ END UPDATE TO DB 16 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF
/************************************************************
**
** Upgrade to version 17.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 16
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 17';
GO
/************************************************* UPDATE TO DB 17 **************************************************/
/****** Object:  Table [dbo].[DiffTypes]    Script Date: 2019-01-18 09:45:25 ******/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 17 WHERE DBVersion = 16

GO
CREATE TABLE [dbo].[DiffTypes](
	[DiffTypeID] [int] IDENTITY(1,1) NOT NULL,
	[Name] [nvarchar](50) NOT NULL,
	[Description] [nvarchar](max) NULL,
	[Priority] [int] NOT NULL,
 CONSTRAINT [PK_DiffTypes] PRIMARY KEY CLUSTERED 
(
	[DiffTypeID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
INSERT [dbo].[DiffTypes] ([Name], [Description], [Priority]) VALUES (N'MISC', 'Unknown difference', 3)
INSERT [dbo].[DiffTypes] ([Name], [Description], [Priority]) VALUES (N'MINOR', 'Less significant difference', 5)
INSERT [dbo].[DiffTypes] ([Name], [Description], [Priority]) VALUES (N'CURRENCY', 'Currency differences', 4)
INSERT [dbo].[DiffTypes] ([Name], [Description], [Priority]) VALUES (N'INVESTIGATE', 'Difference that needs to be investigated', 2)
INSERT [dbo].[DiffTypes] ([Name], [Description], [Priority]) VALUES (N'CRITICAL', 'Very critical difference and must be investigated immediately', 1)
GO
ALTER TABLE [dbo].[ReconGroups] ADD [Unspecified] [decimal](20,2) NULL
GO

/****** Object:  Table [dbo].[AnalysisTemplates]    Script Date: 2019-02-05 07:44:59 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[AnalysisTemplates](
	[AnalysisID] [int] IDENTITY(1,1) NOT NULL,
	[AnalysisName] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_AnalysisTemplates] PRIMARY KEY CLUSTERED 
(
	[AnalysisID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AnalysisGroups]    Script Date: 2019-02-05 07:44:36 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[AnalysisGroups](
	[AnalysisID] [int] NOT NULL,
	[AnalysisGroupID] [int] IDENTITY(1,1) NOT NULL,
	[AnalysisGroupName] [nvarchar](max) NOT NULL,
	[SortingOrder] [int] NOT NULL,
	[XML] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_AnalysisGroups] PRIMARY KEY CLUSTERED 
(
	[AnalysisGroupID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

ALTER TABLE [dbo].[AnalysisGroups]  WITH CHECK ADD  CONSTRAINT [FK_AnalysisGroups_AnalysisTemplates] FOREIGN KEY([AnalysisID])
REFERENCES [dbo].[AnalysisTemplates] ([AnalysisID])
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[AnalysisGroups] CHECK CONSTRAINT [FK_AnalysisGroups_AnalysisTemplates]
GO
/************************************************ END UPDATE TO DB 17 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF

/************************************************************
**
** Upgrade to version 18.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 17
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 18';
GO
/************************************************* UPDATE TO DB 18 **************************************************/
/****** Object:  Table [dbo].[DiffTypes]    Script Date: 2019-01-18 09:45:25 ******/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 18 WHERE DBVersion = 17
GO
/****** Object:  Table [dbo].[AuditLog]    Script Date: 2019-10-25 09:37:34 ******/
CREATE TABLE [dbo].[AuditLog](
    [EventId] [int] IDENTITY(1,1) NOT NULL,
    [JsonData] [nvarchar](max) NULL,
    [TimeStamp] [datetime] NULL,
    [UserId] [int] NULL,
    [EntryType] [nvarchar](50) NULL,
 CONSTRAINT [PK_AuditLog] PRIMARY KEY CLUSTERED 
(
    [EventId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
SET ANSI_PADDING ON
GO
/****** Object:  Index [IX_AuditLog_EntryType]    Script Date: 2019-11-01 11:41:50 ******/
CREATE NONCLUSTERED INDEX [IX_AuditLog_EntryType] ON [dbo].[AuditLog]
(
    [EntryType] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [IX_AuditLog_TimeStamp]    Script Date: 2019-11-01 11:41:50 ******/
CREATE NONCLUSTERED INDEX [IX_AuditLog_TimeStamp] ON [dbo].[AuditLog]
(
    [TimeStamp] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [IX_AuditLog_UserId]    Script Date: 2019-11-01 11:41:50 ******/
CREATE NONCLUSTERED INDEX [IX_AuditLog_UserId] ON [dbo].[AuditLog]
(
    [UserId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
ALTER TABLE [dbo].[GeneralSettings] ADD [RemoveAuditLogsOlderThan] [int] NOT NULL DEFAULT 12
GO
/************************************************ END UPDATE TO DB 18 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF

/************************************************************
**
** Upgrade to version 19.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 18
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 19';
GO
/************************************************* UPDATE TO DB 19 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 19 WHERE DBVersion = 18
GO
UPDATE Entities SET DefaultCurrency = (SELECT CurrencyID FROM Currency WHERE Code = 'SEK') WHERE DefaultCurrency IS NULL
GO
/************************************************ END UPDATE TO DB 19 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)

SET NOEXEC OFF


/************************************************************
**
** Upgrade to version 20.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 19
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 20';
GO
/************************************************* UPDATE TO DB 20 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 20 WHERE DBVersion = 19
GO
/****** Object:  Table [dbo].[GridLayouts]    Script Date: 2021-03-08 13:29:55 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[GridLayouts](
	[GridLayoutID] [int] IDENTITY(1,1) NOT NULL,
	[UserID] [int] NOT NULL,
	[GridType] [int] NOT NULL,
	[Name] [nvarchar](50) NOT NULL,
	[XML] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_GridLayouts] PRIMARY KEY CLUSTERED 
(
	[GridLayoutID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

ALTER TABLE [dbo].[GridLayouts]  WITH CHECK ADD  CONSTRAINT [FK_GridLayouts_Users] FOREIGN KEY([UserID])
REFERENCES [dbo].[Users] ([UserID])
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[GridLayouts] CHECK CONSTRAINT [FK_GridLayouts_Users]
GO
/************************************************ END UPDATE TO DB 20 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF
/************************************************************
**
** Upgrade to version 21.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 20
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 21';
GO
/************************************************* UPDATE TO DB 21 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 21 WHERE DBVersion = 20
GO
ALTER TABLE [dbo].[Entities] ADD Activated BIT NOT NULL DEFAULT 1
GO
/************************************************ END UPDATE TO DB 21 ***********************************************/
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF

/************************************************************
**
** Upgrade to version 22.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 21
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 22';
GO
/************************************************* UPDATE TO DB 22 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 22 WHERE DBVersion = 21
GO
ALTER TABLE [dbo].[Tasks] ADD SharingID UNIQUEIDENTIFIER NULL DEFAULT NULL
GO
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF
/************************************************ END UPDATE TO DB 22 ***********************************************/

/************************************************************
**
** Upgrade to version 23.
**
*************************************************************/
IF (SELECT CurrentVersion FROM #upgrade) <> 22
BEGIN
 SET NOEXEC ON;
END
PRINT 'Upgrading Database to version: 23';
GO
/************************************************* UPDATE TO DB 23 **************************************************/
UPDATE [dbo].[GeneralSettings] SET DBVersion = 23 WHERE DBVersion = 22
GO
ALTER TABLE [dbo].[GeneralSettings] ADD UseZipMethod BIT NOT NULL DEFAULT 0
GO
Update #upgrade SET CurrentVersion = (Select DBVersion FROM GeneralSettings)
SET NOEXEC OFF
/************************************************ END UPDATE TO DB 23 ***********************************************/


/******************************************************
**
** Add new version above
**
*******************************************************/


PRINT 'REINDEX DATABASE, Will cause print outs'
PRINT '---------------------------------';
EXEC sp_MSforeachtable @command1="print '?' DBCC DBREINDEX ('?', ' ', 80)"
GO
EXEC sp_updatestats;
PRINT '---------------------------------';
PRINT 'REINDEX COMPLETE!';

DECLARE @CurrentVersion int;
SELECT @CurrentVersion = CurrentVersion FROM #upgrade;
PRINT 'Upgrade complete to version: ' + STR(@CurrentVersion);
DROP TABLE #upgrade
